@@ -2,10 +2,13 @@ from .chat import Chat, AsyncChat
 from .embeddings import Embeddings, AsyncEmbeddings
 from .tokenization import Tokenization, AsyncTokenization
 from .classification import Classification, AsyncClassification
+from .bot import BotChat, AsyncBotChat
 
 __all__ = [
     "Chat",
+    "BotChat",
     "AsyncChat",
+    "AsyncBotChat",
     "Embeddings",
     "AsyncEmbeddings",
     "Tokenization",
